import { isHmrDataInbound, isHmrDataOutbound } from './hmrData.js';
describe('isHmrDataInbound', () => {
    it('should return false for non-object data', () => {
        expect(isHmrDataInbound(null)).toBe(false);
        expect(isHmrDataInbound(undefined)).toBe(false);
        expect(isHmrDataInbound(42)).toBe(false);
        expect(isHmrDataInbound('string')).toBe(false);
    });
    it('should return false for objects without type property', () => {
        expect(isHmrDataInbound({})).toBe(false);
        expect(isHmrDataInbound({ foo: 'bar' })).toBe(false);
    });
    it('should return true for objects with type "fetch" or "register"', () => {
        expect(isHmrDataInbound({ type: 'fetch' })).toBe(true);
        expect(isHmrDataInbound({ type: 'register' })).toBe(true);
    });
    it('should return false for objects with other type values', () => {
        expect(isHmrDataInbound({ type: 'update' })).toBe(false);
        expect(isHmrDataInbound({ type: 'delete' })).toBe(false);
    });
});
describe('isHmrDataOutbound', () => {
    it('should return false for non-object data', () => {
        expect(isHmrDataOutbound(null)).toBe(false);
        expect(isHmrDataOutbound(undefined)).toBe(false);
        expect(isHmrDataOutbound(42)).toBe(false);
        expect(isHmrDataOutbound('string')).toBe(false);
    });
    it('should return false for objects without type property', () => {
        expect(isHmrDataOutbound({})).toBe(false);
        expect(isHmrDataOutbound({ foo: 'bar' })).toBe(false);
    });
    it('should return false for objects with non-string type property', () => {
        expect(isHmrDataOutbound({ type: 123 })).toBe(false);
        expect(isHmrDataOutbound({ type: true })).toBe(false);
    });
    it('should return true for objects with valid outbound type values', () => {
        expect(isHmrDataOutbound({ type: 'update' })).toBe(true);
        expect(isHmrDataOutbound({ type: 'module-update' })).toBe(true);
        expect(isHmrDataOutbound({ type: 'module-delete' })).toBe(true);
        expect(isHmrDataOutbound({ type: 'error' })).toBe(true);
        expect(isHmrDataOutbound({ type: 'auth-response' })).toBe(true);
    });
    it('should return false for objects with other type values', () => {
        expect(isHmrDataOutbound({ type: 'fetch' })).toBe(false);
        expect(isHmrDataOutbound({ type: 'register' })).toBe(false);
    });
});
//# sourceMappingURL=hmrData.spec.js.map